<?php

declare(strict_types=1);

namespace PrestaShop\Module\GdprCookieConsent\Form;

use PrestaShop\PrestaShop\Core\Configuration\DataConfigurationInterface;
use PrestaShop\PrestaShop\Core\ConfigurationInterface;

/**
 * Configuration is used to save data to configuration table and retrieve from it.
 */
final class GdprConfigurationDataConfiguration implements DataConfigurationInterface
{
    /**
     * @var ConfigurationInterface
     */
    private $configuration;

    /**
     * @var array Configuration keys
     */
    private $configurationKeys = [
        'GDPR_COOKIE_ENABLED',
        'GDPR_COOKIE_MESSAGE',
        'GDPR_COOKIE_ACCEPT',
        'GDPR_COOKIE_DECLINE',
        'GDPR_COOKIE_SETTINGS',
        'GDPR_COOKIE_MORE_INFO',
        'GDPR_COOKIE_MORE_INFO_URL',
        'GDPR_COOKIE_DATA_CONTROLLER',
        'GDPR_COOKIE_RETENTION_PERIOD',
        'GDPR_COOKIE_THIRD_PARTIES',
        'GDPR_COOKIE_MANAGE_TEXT',
        'GDPR_COOKIE_ONLY_REQUIRED',
    ];

    public function __construct(ConfigurationInterface $configuration)
    {
        $this->configuration = $configuration;
    }

    /**
     * @return array
     */
    public function getConfiguration(): array
    {
        $config = [];
        foreach ($this->configurationKeys as $key) {
            $config[$key] = $this->configuration->get($key);
        }

        return $config;
    }

    /**
     * @param array $configuration
     * @return array
     */
    public function updateConfiguration(array $configuration): array
    {
        $errors = [];

        if ($this->validateConfiguration($configuration)) {
            foreach ($this->configurationKeys as $key) {
                if (isset($configuration[$key])) {
                    $this->configuration->set($key, $configuration[$key]);
                }
            }
        }

        return $errors;
    }

    /**
     * @param array $configuration
     * @return bool
     */
    public function validateConfiguration(array $configuration): bool
    {
        return isset($configuration['GDPR_COOKIE_MESSAGE']) &&
            isset($configuration['GDPR_COOKIE_ACCEPT']) &&
            isset($configuration['GDPR_COOKIE_DECLINE']) &&
            isset($configuration['GDPR_COOKIE_SETTINGS']) &&
            isset($configuration['GDPR_COOKIE_MORE_INFO']) &&
            isset($configuration['GDPR_COOKIE_MORE_INFO_URL']) &&
            isset($configuration['GDPR_COOKIE_DATA_CONTROLLER']) &&
            isset($configuration['GDPR_COOKIE_RETENTION_PERIOD']) &&
            isset($configuration['GDPR_COOKIE_THIRD_PARTIES']) &&
            isset($configuration['GDPR_COOKIE_MANAGE_TEXT']);
    }
}