<?php

declare(strict_types=1);

namespace PrestaShop\Module\GdprCookieConsent\Form;

use PrestaShopBundle\Form\Admin\Type\SwitchType;
use PrestaShopBundle\Form\Admin\Type\TranslatableType;
use PrestaShopBundle\Form\Admin\Type\TranslatorAwareType;
use Symfony\Component\Form\Extension\Core\Type\TextareaType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\Extension\Core\Type\UrlType;
use Symfony\Component\Form\FormBuilderInterface;

class GdprConfigurationFormType extends TranslatorAwareType
{
    public function buildForm(FormBuilderInterface $builder, array $options): void
    {
        $builder
            ->add('GDPR_COOKIE_ENABLED', SwitchType::class, [
                'label' => $this->trans('Enable Cookie Consent', 'Modules.Gdprcookieconsent.Admin'),
                'help' => $this->trans('Enable or disable the cookie consent banner', 'Modules.Gdprcookieconsent.Admin'),
            ])
            ->add('GDPR_COOKIE_MESSAGE', TranslatableType::class, [
                'label' => $this->trans('Cookie Consent Message', 'Modules.Gdprcookieconsent.Admin'),
                'type' => TextareaType::class,
                'required' => true,
            ])
            ->add('GDPR_COOKIE_DATA_CONTROLLER', TranslatableType::class, [
                'label' => $this->trans('Data Controller', 'Modules.Gdprcookieconsent.Admin'),
                'help' => $this->trans('Your company/organization name', 'Modules.Gdprcookieconsent.Admin'),
                'type' => TextType::class,
                'required' => true,
            ])
            ->add('GDPR_COOKIE_RETENTION_PERIOD', TranslatableType::class, [
                'label' => $this->trans('Cookie Retention Period', 'Modules.Gdprcookieconsent.Admin'),
                'help' => $this->trans('How long cookies will be stored (e.g., 365 days)', 'Modules.Gdprcookieconsent.Admin'),
                'type' => TextType::class,
                'required' => true,
            ])
            ->add('GDPR_COOKIE_THIRD_PARTIES', TranslatableType::class, [
                'label' => $this->trans('Third-Party Recipients', 'Modules.Gdprcookieconsent.Admin'),
                'help' => $this->trans('List third parties that receive cookie data', 'Modules.Gdprcookieconsent.Admin'),
                'type' => TextareaType::class,
                'required' => true,
            ])
            ->add('GDPR_COOKIE_ACCEPT', TranslatableType::class, [
                'label' => $this->trans('Accept Button Text', 'Modules.Gdprcookieconsent.Admin'),
                'type' => TextType::class,
                'required' => true,
            ])
            ->add('GDPR_COOKIE_DECLINE', TranslatableType::class, [
                'label' => $this->trans('Decline Button Text', 'Modules.Gdprcookieconsent.Admin'),
                'type' => TextType::class,
                'required' => true,
            ])
            ->add('GDPR_COOKIE_SETTINGS', TranslatableType::class, [
                'label' => $this->trans('Settings Button Text', 'Modules.Gdprcookieconsent.Admin'),
                'type' => TextType::class,
                'required' => true,
            ])
            ->add('GDPR_COOKIE_MANAGE_TEXT', TranslatableType::class, [
                'label' => $this->trans('Manage Preferences Text', 'Modules.Gdprcookieconsent.Admin'),
                'help' => $this->trans('Text for the manage preferences button (displayed after consent is given)', 'Modules.Gdprcookieconsent.Admin'),
                'type' => TextType::class,
                'required' => true,
            ])
            ->add('GDPR_COOKIE_MORE_INFO', TranslatableType::class, [
                'label' => $this->trans('More Info Button Text', 'Modules.Gdprcookieconsent.Admin'),
                'type' => TextType::class,
                'required' => true,
            ])
            ->add('GDPR_COOKIE_MORE_INFO_URL', UrlType::class, [
                'label' => $this->trans('More Info URL', 'Modules.Gdprcookieconsent.Admin'),
                'help' => $this->trans('URL to your Privacy Policy page', 'Modules.Gdprcookieconsent.Admin'),
                'required' => true,
            ])
            ->add('GDPR_COOKIE_ONLY_REQUIRED', SwitchType::class, [
                'label' => $this->trans('This cookie types are used', 'Modules.Gdprcookieconsent.Admin'),
                'help' => $this->trans('If this option is enabled, no config modal will be rendered and there will only be a single button to hide the cookie notice.', 'Modules.Gdprcookieconsent.Admin'),
                'choices' => [
                    $this->trans('Nessessary only', 'Modules.Gdprcookieconsent.Admin') => true,
                    $this->trans('All cookies', 'Modules.Gdprcookieconsent.Admin') => false,
                ],
            ]);
    }
}